@@ -130,9 +130,12 @@ def main():
     params_file = os.path.join(BeagleDirectories.results_dir, args.json_file_triangle)
 
     # Compute the summary catalogue
-    summary_catalogue = BeagleSummaryCatalogue(credible_intervals=args.credible_interval, n_proc=args.n_proc)
+    summary_catalogue = BeagleSummaryCatalogue(credible_intervals=args.credible_interval, 
+                                               n_proc=args.n_proc, 
+                                              overwrite=args.overwrite,
+                                              flatten_columns=args.flatten_columns)
     if args.compute_summary:
-        if not summary_catalogue.exists():
+        if not summary_catalogue.exists() or args.overwrite:
             summary_catalogue.compute(file_list)
 
     if args.latex_table_params is not None:
@@ -157,7 +160,7 @@ def main():
     # ---------------------------------------------------------
     # --------- Post-processing of photometric data -----------
     # ---------------------------------------------------------
-    if has_photometry:
+    if has_photometry and args.plot_marginal:
 
         # We can load a set of photometric filters
         try:
@@ -186,7 +189,7 @@ def main():
     # ---------------------------------------------------------
     # --------- Post-processing of spectral indices data -----------
     # ---------------------------------------------------------
-    if has_spec_indices and args.line_labels_json:
+    if has_spec_indices and args.line_labels_json and args.plot_marginal:
 
         # Initialize an instance of the main "SpectralIndices" class
         my_spec_indices = SpectralIndices(**args_dict)
@@ -201,7 +204,7 @@ def main():
     # ---------------------------------------------------------
     # -------- Post-processing of spectroscopic data ----------
     # ---------------------------------------------------------
-    if has_spectra:
+    if has_spectra and args.plot_marginal:
 
         # Initialize an instance of the main "Spectrum" class
         my_spectrum = Spectrum(**args_dict)
@@ -235,6 +238,9 @@ def main():
                     file_names.append(line)
                     break
 
+        if len(file_names) != len(IDs):
+            raise ValueError("Cannot match object IDs and file names of the input spectra!")
+
     # Create "pool" of processes
     if args.n_proc > 1:
         pool = ProcessingPool(nodes=args.n_proc)
